Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ANGELA MARIA MAZOCCO EIRELI:29391008000108
CNPJ: 29.391.008/0001-08 Inscrição Estadual: 3820023536
RODOVIA BR 386 TABAI, 2555, BERTO CIRIO, NOVA SANTA RITA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 31453 Série: 0 Data de Emissão: 28/09/2019 19:43:42
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0929 3910 0800 0108 6500 0000 0314 5310 4061 0373
Protocolo de Autorização: 143191332678201
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
43 | ALA MINUTA | 2 | UN | 20,9 | 41,80
16 | SUCO COPO | 1 | UN | 4,6 | 4,60
Valor total R$ | 46,40
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:27